==> senior_authentication-0.2.3.tar.gz: lib/src/screens/forgot_password/forgot_password_form.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:senior_authentication/senior_authentication.dart';
import 'package:senior_authentication/src/screens/forgot_password/bloc/forgot_password_bloc.dart';
import 'package:senior_authentication/src/screens/forgot_password/bloc/forgot_password_form_state.dart';
import 'package:senior_authentication/src/screens/forgot_password/forgot_password_recaptcha.dart';

class ForgotPasswordForm extends StatelessWidget {
  ForgotPasswordForm({
    Key? key,
    required this.username,
    required this.changePasswordSetting,
  }) : super(key: key);

  final String username;
  final ChangePasswordSettings changePasswordSetting;
  final _formKey = GlobalKey<FormState>();
  @override
  Widget build(BuildContext context) {
    return BlocListener<ForgotPasswordBloc, ForgotPasswordState>(
      listener: (context, state) {
        final formState = state.formState;

        if (formState is ForgotPasswordFormError) {
          ScaffoldMessenger.of(context)
            ..hideCurrentSnackBar()
            ..showSnackBar(
              const SnackBar(
                content: Text('Verifique seu e-mail e tente novamente'),
              ),
            );
        }
      },
      child: BlocBuilder<ForgotPasswordBloc, ForgotPasswordState>(
          builder: (context, state) {
        if (state.formState is ForgotPasswordFormSuccess) {
          return const _SuccessMessage();
        }

        return _FormForgotPassword(
          username: username,
          formKey: _formKey,
          changePasswordSetting: changePasswordSetting,
        );
      }),
    );
  }
}

class _FormForgotPassword extends StatelessWidget {
  const _FormForgotPassword({
    Key? key,
    required this.username,
    required this.formKey,
    required this.changePasswordSetting,
  }) : super(key: key);

  final GlobalKey<FormState> formKey;
  final String username;
  final ChangePasswordSettings changePasswordSetting;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ForgotPasswordBloc, ForgotPasswordState>(
        builder: (context, state) {
      return Form(
        key: formKey,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const SizedBox(height: 48.0),
            _InsertEmailText(username: username),
            const SizedBox(height: 40.0),
            _EmailInput(username: username),
            const SizedBox(height: 80.0),
            const Spacer(),
            _ResetPasswordButton(
              formKey: formKey,
              username: username,
              changePasswordSetting: changePasswordSetting,
            ),
            const SizedBox(height: 40),
          ],
        ),
      );
    });
  }
}

class _InsertEmailText extends StatelessWidget {
  const _InsertEmailText({Key? key, required this.username}) : super(key: key);

  final String username;

  @override
  Widget build(BuildContext context) {
    var name = username.split('@')[0];
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          'Olá,',
          style: GoogleFonts.inter(
              color: Colors.black87, fontSize: 32, fontWeight: FontWeight.w600),
        ),
        Text(
          name,
          style: GoogleFonts.inter(
              color: Colors.black87, fontSize: 32, fontWeight: FontWeight.w600),
        ),
        Text(
          username,
          style: GoogleFonts.inter(
              color: const Color(0xFF808080),
              fontSize: 16,
              fontWeight: FontWeight.w500),
        ),
      ],
    );
  }
}

class _EmailInput extends StatelessWidget {
  const _EmailInput({Key? key, required this.username}) : super(key: key);

  final String username;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ForgotPasswordBloc, ForgotPasswordState>(
        builder: (context, state) {
      return TextFormField(
        key: const Key('forgotPasswordForm_usernameInput_textField'),
        validator: (value) {
          return state.isValidUsername ? null : 'E-mail inválido.';
        },
        onChanged: (value) => context.read<ForgotPasswordBloc>().add(
              UsernameChangedEvent(
                username: value,
              ),
            ),
        initialValue: username,
        keyboardType: TextInputType.text,
        cursorColor: Colors.black87,
        decoration: InputDecoration(
          focusedBorder: const UnderlineInputBorder(
            borderSide: BorderSide(
              color: Colors.black87,
            ),
          ),
          border: const UnderlineInputBorder(),
          prefixIcon: const Icon(
            Icons.email,
            color: Colors.black87,
          ),
          labelText: 'E-mail',
          labelStyle: GoogleFonts.openSans(
            color: Colors.black87,
            fontSize: 16,
            fontWeight: FontWeight.w400,
          ),
          helperText:
              'Insira o e-mail que você utiliza na Senior X para receber as '
              'instruções de recuperação de senha',
          helperMaxLines: 4,
          helperStyle: GoogleFonts.openSans(
              color: const Color(0xFF4D4D4D),
              fontSize: 12,
              fontWeight: FontWeight.w400),
          errorStyle: GoogleFonts.openSans(
              color: const Color(0xFFA94442),
              fontSize: 12,
              fontWeight: FontWeight.w400),
        ),
      );
    });
  }
}

class _ResetPasswordButton extends StatelessWidget {
  const _ResetPasswordButton({
    required this.formKey,
    required this.username,
    required this.changePasswordSetting,
  });

  final String username;
  final ChangePasswordSettings changePasswordSetting;
  final GlobalKey<FormState> formKey;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ForgotPasswordBloc, ForgotPasswordState>(
        builder: (context, state) {
      if (state.formState is ForgotPasswordFormLoading) {
        return const Center(
          child: CircularProgressIndicator(
            backgroundColor: Color(0xFF12A885),
            valueColor: AlwaysStoppedAnimation<Color>(
              Color(0xFF0E866A),
            ),
          ),
        );
      }

      return ElevatedButton(
        key: const Key('forgotPasswordForm_recovery_elevattedButton'),
        onPressed: () async {
          String? captcha = await Navigator.of(context).push(
            PageRouteBuilder(
              opaque: false,
              pageBuilder: (_, __, ___) => ForgotPasswordRecaptcha(
                changePasswordSetting: changePasswordSetting,
              ),
            ),
          );

          if (formKey.currentState == null ||
              !formKey.currentState!.validate()) {
            ScaffoldMessenger.of(context)
              ..hideCurrentSnackBar()
              ..showSnackBar(
                const SnackBar(
                  content: Text(
                    'Por favor, verifique os campos e tente novamente.',
                  ),
                ),
              );

            return;
          }

          if (captcha == null || captcha.isEmpty) {
            ScaffoldMessenger.of(context)
              ..hideCurrentSnackBar()
              ..showSnackBar(
                const SnackBar(
                  content: Text(
                    'Não foi possível validar o reCaptcha. Por favor, tente novamente.',
                  ),
                ),
              );
            return;
          }

          context.read<ForgotPasswordBloc>().add(
                ResetPasswordEvent(
                  captcha: captcha,
                  baseUrl: changePasswordSetting.url ?? '',
                ),
              );
        },
        style: ButtonStyle(
          shape: MaterialStateProperty.all<RoundedRectangleBorder>(
            RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(6.0),
            ),
          ),
          backgroundColor: MaterialStateProperty.resolveWith<Color>(
            (states) => const Color(0xFF0E866A),
          ),
        ),
        child: Container(
          height: 48,
          width: double.infinity,
          alignment: Alignment.center,
          child: Text(
            'Confirmar e-mail',
            style: GoogleFonts.inter(
                fontSize: 18, fontWeight: FontWeight.w700, color: Colors.white),
          ),
        ),
      );
    });
  }
}

class _SuccessMessage extends StatelessWidget {
  const _SuccessMessage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          const Spacer(),
          const Icon(
            Icons.check_rounded,
            color: Color(0xFF0E866A),
            size: 150.0,
          ),
          const SizedBox(height: 10),
          Text(
            'Confira seu e-mail com as instruções para recuperar '
            'sua senha.',
            style: GoogleFonts.inter(
                color: const Color(0xFF808080),
                fontSize: 20,
                fontWeight: FontWeight.w600),
            textAlign: TextAlign.center,
          ),
          const Spacer(),
          ElevatedButton(
            key: const Key('forgotPasswordForm_goback_elevattedButton'),
            onPressed: () {
              Navigator.pop(context);
            },
            style: ButtonStyle(
              shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(6.0),
                ),
              ),
              backgroundColor: MaterialStateProperty.resolveWith<Color>(
                (states) => const Color(0xFF0E866A),
              ),
            ),
            child: Container(
              height: 48,
              width: double.infinity,
              alignment: Alignment.center,
              child: Text(
                'Voltar',
                style: GoogleFonts.inter(
                    fontSize: 18.0,
                    fontWeight: FontWeight.w700,
                    color: Colors.white),
              ),
            ),
          ),
          const SizedBox(height: 56),
        ],
      ),
    );
  }
}

==> senior_authentication-0.3.0.tar.gz: lib/src/screens/forgot_password/forgot_password_form.dart <==
import 'dart:io' show Platform;

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:google_fonts/google_fonts.dart';

import '../../../senior_authentication.dart';
import 'bloc/forgot_password_bloc.dart';
import 'bloc/forgot_password_form_state.dart';
import 'forgot_password_recaptcha.dart';

class ForgotPasswordForm extends StatelessWidget {
  ForgotPasswordForm({
    Key? key,
    required this.username,
    required this.changePasswordSetting,
  }) : super(key: key);

  final String username;
  final ChangePasswordSettings changePasswordSetting;
  final _formKey = GlobalKey<FormState>();
  @override
  Widget build(BuildContext context) {
    return BlocListener<ForgotPasswordBloc, ForgotPasswordState>(
      listener: (context, state) {
        final formState = state.formState;

        if (formState is ForgotPasswordFormError) {
          ScaffoldMessenger.of(context)
            ..hideCurrentSnackBar()
            ..showSnackBar(
              const SnackBar(
                content: Text('Verifique seu e-mail e tente novamente'),
              ),
            );
        }
      },
      child: BlocBuilder<ForgotPasswordBloc, ForgotPasswordState>(
          builder: (context, state) {
        if (state.formState is ForgotPasswordFormSuccess) {
          return const _SuccessMessage();
        }

        return _FormForgotPassword(
          username: username,
          formKey: _formKey,
          changePasswordSetting: changePasswordSetting,
        );
      }),
    );
  }
}

class _FormForgotPassword extends StatelessWidget {
  const _FormForgotPassword({
    Key? key,
    required this.username,
    required this.formKey,
    required this.changePasswordSetting,
  }) : super(key: key);

  final GlobalKey<FormState> formKey;
  final String username;
  final ChangePasswordSettings changePasswordSetting;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ForgotPasswordBloc, ForgotPasswordState>(
        builder: (context, state) {
      return Form(
        key: formKey,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const SizedBox(height: 48.0),
            _InsertEmailText(username: username),
            const SizedBox(height: 40.0),
            _EmailInput(username: username),
            const SizedBox(height: 80.0),
            const Spacer(),
            _ResetPasswordButton(
              formKey: formKey,
              username: username,
              changePasswordSetting: changePasswordSetting,
            ),
            const SizedBox(height: 40),
          ],
        ),
      );
    });
  }
}

class _InsertEmailText extends StatelessWidget {
  const _InsertEmailText({Key? key, required this.username}) : super(key: key);

  final String username;

  @override
  Widget build(BuildContext context) {
    var name = username.split('@')[0];
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          'Olá,',
          style: GoogleFonts.inter(
              color: Colors.black87, fontSize: 32, fontWeight: FontWeight.w600),
        ),
        Text(
          name,
          style: GoogleFonts.inter(
              color: Colors.black87, fontSize: 32, fontWeight: FontWeight.w600),
        ),
        Text(
          username,
          style: GoogleFonts.inter(
              color: const Color(0xFF808080),
              fontSize: 16,
              fontWeight: FontWeight.w500),
        ),
      ],
    );
  }
}

class _EmailInput extends StatelessWidget {
  const _EmailInput({Key? key, required this.username}) : super(key: key);

  final String username;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ForgotPasswordBloc, ForgotPasswordState>(
        builder: (context, state) {
      return TextFormField(
        autocorrect: Platform.isAndroid,
        key: const Key('forgotPasswordForm_usernameInput_textField'),
        validator: (value) {
          return state.isValidUsername ? null : 'E-mail inválido.';
        },
        onChanged: (value) => context.read<ForgotPasswordBloc>().add(
              UsernameChangedEvent(
                username: value,
              ),
            ),
        initialValue: username,
        keyboardType: TextInputType.text,
        cursorColor: Colors.black87,
        decoration: InputDecoration(
          focusedBorder: const UnderlineInputBorder(
            borderSide: BorderSide(
              color: Colors.black87,
            ),
          ),
          border: const UnderlineInputBorder(),
          prefixIcon: const Icon(
            Icons.email,
            color: Colors.black87,
          ),
          labelText: 'E-mail',
          labelStyle: GoogleFonts.openSans(
            color: Colors.black87,
            fontSize: 16,
            fontWeight: FontWeight.w400,
          ),
          helperText:
              'Insira o e-mail que você utiliza na Senior X para receber as '
              'instruções de recuperação de senha',
          helperMaxLines: 4,
          helperStyle: GoogleFonts.openSans(
              color: const Color(0xFF4D4D4D),
              fontSize: 12,
              fontWeight: FontWeight.w400),
          errorStyle: GoogleFonts.openSans(
              color: const Color(0xFFA94442),
              fontSize: 12,
              fontWeight: FontWeight.w400),
        ),
      );
    });
  }
}

class _ResetPasswordButton extends StatelessWidget {
  const _ResetPasswordButton({
    required this.formKey,
    required this.username,
    required this.changePasswordSetting,
  });

  final String username;
  final ChangePasswordSettings changePasswordSetting;
  final GlobalKey<FormState> formKey;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ForgotPasswordBloc, ForgotPasswordState>(
        builder: (context, state) {
      if (state.formState is ForgotPasswordFormLoading) {
        return const Center(
          child: CircularProgressIndicator(
            backgroundColor: Color(0xFF12A885),
            valueColor: AlwaysStoppedAnimation<Color>(
              Color(0xFF0E866A),
            ),
          ),
        );
      }

      return ElevatedButton(
        key: const Key('forgotPasswordForm_recovery_elevattedButton'),
        onPressed: () async {
          String? captcha = await Navigator.of(context).push(
            PageRouteBuilder(
              opaque: false,
              pageBuilder: (_, __, ___) => ForgotPasswordRecaptcha(
                changePasswordSetting: changePasswordSetting,
              ),
            ),
          );

          if (formKey.currentState == null ||
              !formKey.currentState!.validate()) {
            ScaffoldMessenger.of(context)
              ..hideCurrentSnackBar()
              ..showSnackBar(
                const SnackBar(
                  content: Text(
                    'Por favor, verifique os campos e tente novamente.',
                  ),
                ),
              );

            return;
          }

          if (captcha == null || captcha.isEmpty) {
            ScaffoldMessenger.of(context)
              ..hideCurrentSnackBar()
              ..showSnackBar(
                const SnackBar(
                  content: Text(
                    'Não foi possível validar o reCaptcha. Por favor, tente novamente.',
                  ),
                ),
              );
            return;
          }

          context.read<ForgotPasswordBloc>().add(
                ResetPasswordEvent(
                  captcha: captcha,
                  baseUrl: changePasswordSetting.url ?? '',
                ),
              );
        },
        style: ButtonStyle(
          shape: MaterialStateProperty.all<RoundedRectangleBorder>(
            RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(6.0),
            ),
          ),
          backgroundColor: MaterialStateProperty.resolveWith<Color>(
            (states) => const Color(0xFF0E866A),
          ),
        ),
        child: Container(
          height: 48,
          width: double.infinity,
          alignment: Alignment.center,
          child: Text(
            'Confirmar e-mail',
            style: GoogleFonts.inter(
                fontSize: 18, fontWeight: FontWeight.w700, color: Colors.white),
          ),
        ),
      );
    });
  }
}

class _SuccessMessage extends StatelessWidget {
  const _SuccessMessage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          const Spacer(),
          const Icon(
            Icons.check_rounded,
            color: Color(0xFF0E866A),
            size: 150.0,
          ),
          const SizedBox(height: 10),
          Text(
            'Confira seu e-mail com as instruções para recuperar '
            'sua senha.',
            style: GoogleFonts.inter(
                color: const Color(0xFF808080),
                fontSize: 20,
                fontWeight: FontWeight.w600),
            textAlign: TextAlign.center,
          ),
          const Spacer(),
          ElevatedButton(
            key: const Key('forgotPasswordForm_goback_elevattedButton'),
            onPressed: () {
              Navigator.pop(context);
            },
            style: ButtonStyle(
              shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(6.0),
                ),
              ),
              backgroundColor: MaterialStateProperty.resolveWith<Color>(
                (states) => const Color(0xFF0E866A),
              ),
            ),
            child: Container(
              height: 48,
              width: double.infinity,
              alignment: Alignment.center,
              child: Text(
                'Voltar',
                style: GoogleFonts.inter(
                    fontSize: 18.0,
                    fontWeight: FontWeight.w700,
                    color: Colors.white),
              ),
            ),
          ),
          const SizedBox(height: 56),
        ],
      ),
    );
  }
}
